@@ -31,10 +31,8 @@
 #include "nautilus-tree-view-drag-dest.h"
 
 #include <eel/eel-gtk-macros.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-macros.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include "nautilus-file-dnd.h"
 #include "nautilus-icon-dnd.h"
 #include "nautilus-link.h"
@@ -290,7 +288,7 @@ file_for_path (NautilusTreeViewDragDest *dest, GtkTreePath *path)
 
 		file = NULL;
 		if (uri != NULL) {
-			file = nautilus_file_get (uri);
+			file = nautilus_file_get_by_uri (uri);
 		}
 		
 		g_free (uri);
@@ -582,11 +580,13 @@ receive_uris (NautilusTreeViewDragDest *dest,
 	}
 
 	if (context->action > 0) {
-		g_signal_emit (dest, signals[MOVE_COPY_ITEMS], 0,
-			       source_uris, 
-			       drop_target,
-			       context->action,
-			       x, y);
+		if (!nautilus_drag_uris_local (drop_target, source_uris)) {
+			g_signal_emit (dest, signals[MOVE_COPY_ITEMS], 0,
+				       source_uris, 
+				       drop_target,
+				       context->action,
+				       x, y);
+		}
 	}
 
 	g_free (drop_target);
@@ -706,7 +706,7 @@ receive_dropped_keyword (NautilusTreeViewDragDest *dest,
 	drop_target_uri = get_drop_target_uri_at_pos (dest, x, y);
 	g_assert (drop_target_uri != NULL);
 
-	drop_target_file = nautilus_file_get (drop_target_uri);
+	drop_target_file = nautilus_file_get_by_uri (drop_target_uri);
 
 	if (drop_target_file != NULL) {
 		nautilus_drag_file_receive_dropped_keyword (drop_target_file,
